==> ClassifyR_1.12.0.tar.gz: ClassifyR/R/DMDselection.R <==
# Mean or Median, Three Kinds of Deviations.
setGeneric("DMDselection", function(expression, ...)
           {standardGeneric("DMDselection")})

setMethod("DMDselection", "matrix", function(expression, classes, ...)
{ 
  colnames(expression) <- NULL # Might be duplicates because of sampling with replacement.  
  features <- rownames(expression)
  groupsTable <- data.frame(class = classes)
  exprSet <- ExpressionSet(expression, AnnotatedDataFrame(groupsTable))
  if(length(features) > 0) featureNames(exprSet) <- features
  DMDselection(exprSet, ...)
})

setMethod("DMDselection", "ExpressionSet", 
          function(expression, datasetName, trainParams, predictParams, resubstituteParams,
                   ..., selectionName = "Differences of Medians and Deviations", verbose = 3)
{
  if(verbose == 3)
    message("Selecting features by DMD.")
            
  classes <- pData(expression)[, "class"]
  oneClassExpression <- exprs(expression[, classes == levels(classes)[1]])
  otherClassExpression <- exprs(expression[, classes == levels(classes)[2]])
  oneClassDistribution <- getLocationsAndScales(oneClassExpression, ...)
  otherClassDistribution <- getLocationsAndScales(otherClassExpression, ...)
  locationDifference <- oneClassDistribution[[1]] - otherClassDistribution[[1]]
  divergence <- abs(locationDifference) + abs(oneClassDistribution[[2]] - otherClassDistribution[[2]])
  orderedFeatures <- order(divergence, decreasing = TRUE)
  
  .pickRows(expression, datasetName, trainParams, predictParams, resubstituteParams,
            orderedFeatures, selectionName, verbose)
})

==> ClassifyR_1.12.2.tar.gz: ClassifyR/R/DMDselection.R <==
# Mean or Median, Three Kinds of Deviations.
setGeneric("DMDselection", function(expression, ...)
           {standardGeneric("DMDselection")})

setMethod("DMDselection", "matrix", function(expression, classes, ...)
{
  features <- rownames(expression)
  groupsTable <- data.frame(class = classes, row.names = colnames(expression))
  exprSet <- ExpressionSet(expression, AnnotatedDataFrame(groupsTable))
  if(length(features) > 0) featureNames(exprSet) <- features
  DMDselection(exprSet, ...)
})

setMethod("DMDselection", "ExpressionSet", 
          function(expression, datasetName, trainParams, predictParams, resubstituteParams,
                   ..., selectionName = "Differences of Medians and Deviations", verbose = 3)
{
  if(verbose == 3)
    message("Selecting features by DMD.")
            
  classes <- pData(expression)[, "class"]
  oneClassExpression <- exprs(expression[, classes == levels(classes)[1]])
  otherClassExpression <- exprs(expression[, classes == levels(classes)[2]])
  oneClassDistribution <- getLocationsAndScales(oneClassExpression, ...)
  otherClassDistribution <- getLocationsAndScales(otherClassExpression, ...)
  locationDifference <- oneClassDistribution[[1]] - otherClassDistribution[[1]]
  divergence <- abs(locationDifference) + abs(oneClassDistribution[[2]] - otherClassDistribution[[2]])
  orderedFeatures <- order(divergence, decreasing = TRUE)
  
  .pickRows(expression, datasetName, trainParams, predictParams, resubstituteParams,
            orderedFeatures, selectionName, verbose)
})
